@@ -23,7 +23,6 @@ import time
 import tempfile
 
 from stratuslab.CloudConnectorFactory import CloudConnectorFactory
-from stratuslab.Runner import Runner
 from stratuslab.Util import sshCmd
 from stratuslab.Util import sshCmdWithOutput
 from stratuslab.Util import waitUntilPingOrTimeout
@@ -43,11 +42,13 @@ from stratuslab.system import Systems
 from stratuslab import Defaults
 from stratuslab.marketplace.ManifestDownloader import ManifestDownloader
 from stratuslab.Monitor import Monitor
+from stratuslab.vm_manager.vm_manager import VmManager
+from stratuslab.vm_manager.vm_manager_factory import VmManagerFactory
+
 
 class Creator(object):
-
     VM_START_TIMEOUT = 60 * 10
-    VM_PING_TIMEPUT = 60 * 5
+    VM_PING_TIMEOUT = 60 * 5
 
     excludeFromCreatedImageDefault = ['/tmp/*',
                                       '/etc/ssh/ssh_host_*',
@@ -85,9 +86,9 @@ class Creator(object):
         self.signManifest = True
 
         self.vmStartTimeout = self.VM_START_TIMEOUT
-        self.vmPingTimeout = self.VM_PING_TIMEPUT
+        self.vmPingTimeout = self.VM_PING_TIMEOUT
 
-        self.options = Runner.defaultRunOptions()
+        self.options = VmManager.defaultRunOptions()
         self.options.update(configHolder.options)
         self.configHolder.options.update(self.options)
 
@@ -118,8 +119,8 @@ class Creator(object):
         self.imageFileBundled = ''
 
         self.excludeFromCreatedImage = \
-                                self.excludeFromCreatedImageDefault + \
-                                self.options.get('excludeFromCreatedImage','').split(',')
+            self.excludeFromCreatedImageDefault + \
+            self.options.get('excludeFromCreatedImage', '').split(',')
 
         self.installer = self.options.get('installer')
 
@@ -145,7 +146,7 @@ class Creator(object):
         try:
             self.buildNodeIncrement()
             self._printAction('Finished building image increment.')
-            self._printAction('Please check %s for new image ID and instruction.' %\
+            self._printAction('Please check %s for new image ID and instruction.' %
                               self.authorEmail)
         finally:
             self._shutdownNode()
@@ -216,14 +217,13 @@ class Creator(object):
         cmd = 'true'
         try:
             self._sshCmdWithOutputVerb(cmd)
-        except ExecutionException, e:
+        except ExecutionException:
             sleepTime = 6
             maxCount = 40
             counter = 0
             while True:
                 try:
-                    self.printDetail('Sleeping %i sec. Retry %i out of %i.' % \
-                                     (sleepTime, counter+1, maxCount))
+                    self.printDetail('Sleeping %i sec. Retry %i out of %i.' % (sleepTime, counter + 1, maxCount))
                     time.sleep(sleepTime)
                     self._sshCmdWithOutputVerb(cmd)
                     break
@@ -241,27 +241,27 @@ class Creator(object):
         image.checkImageExists(self.image)
 
     def _getCreateImageTemplateDict(self):
-        return {Runner.CREATE_IMAGE_KEY_CREATOR_EMAIL: self.authorEmail,
-                Runner.CREATE_IMAGE_KEY_CREATOR_NAME: self.author,
-                Runner.CREATE_IMAGE_KEY_NEWIMAGE_TITLE: self.title,
-                Runner.CREATE_IMAGE_KEY_NEWIMAGE_COMMENT: self.comment,
-                Runner.CREATE_IMAGE_KEY_NEWIMAGE_VERSION: self.newImageGroupVersion,
-                Runner.CREATE_IMAGE_KEY_NEWIMAGE_MARKETPLACE: self.marketplaceEndpointNewimage }
+        return {VmManager.CREATE_IMAGE_KEY_CREATOR_EMAIL: self.authorEmail,
+                VmManager.CREATE_IMAGE_KEY_CREATOR_NAME: self.author,
+                VmManager.CREATE_IMAGE_KEY_NEWIMAGE_TITLE: self.title,
+                VmManager.CREATE_IMAGE_KEY_NEWIMAGE_COMMENT: self.comment,
+                VmManager.CREATE_IMAGE_KEY_NEWIMAGE_VERSION: self.newImageGroupVersion,
+                VmManager.CREATE_IMAGE_KEY_NEWIMAGE_MARKETPLACE: self.marketplaceEndpointNewimage}
 
     def createRunner(self):
         self.__createRunner()
 
     def __createRunner(self):
-        self.configHolder.set('vmName', 
+        self.configHolder.set('vmName',
                               '%s: %s' % (self.vmName, Util.getTimeInIso8601()))
         self.configHolder.set('noCheckImageUrl', True)
 
         self.configHolder.set('saveDisk', True)
 
-        self.runner = Runner(self.image, self.configHolder)
+        self.runner = VmManagerFactory.create(self.image, self.configHolder)
 
         self.runner.updateCreateImageTemplateData(
-                                    self._getCreateImageTemplateDict())
+            self._getCreateImageTemplateDict())
 
     def _startMachine(self):
         self._printStep('Starting base image')
@@ -279,15 +279,15 @@ class Creator(object):
         self._printStep('Waiting for machine to boot')
         vmStarted = self.runner.waitUntilVmRunningOrTimeout(self.vmId,
                                                             self.vmStartTimeout,
-                                                            failOn=('Failed'))
+                                                            failOn='Failed')
         if not vmStarted:
             if self.runner.getVmState(self.vmId) == 'Failed':
                 msg = 'Failed to start VM (id=%s, ip=%s): %s' % \
-                                    (self.vmId, self.vmAddress,
-                                     self._getVmFailureMessage(self.vmId))
+                      (self.vmId, self.vmAddress,
+                       self._getVmFailureMessage(self.vmId))
             else:
                 msg = 'Failed to start VM within %i seconds (id=%s, ip=%s)' % \
-                                    (self.vmStartTimeout, self.vmId, self.vmAddress)
+                      (self.vmStartTimeout, self.vmId, self.vmAddress)
             self.printDetail(msg)
             self._killMachine()
             self._printError(msg)
@@ -296,7 +296,7 @@ class Creator(object):
         self._printStep('Shutting down machine')
 
         if self.getVmState() != 'Failed':
-                self.cloud.vmStop(self.vmId)
+            self.cloud.vmStop(self.vmId)
 
     def _killMachine(self):
         self._printStep('Killing machine')
@@ -314,15 +314,15 @@ class Creator(object):
         if self.shutdownVm:
             self._stopMachine()
         else:
-            self._printStep('Machine ready for your usage')
-            print '\n\tMachine IP: %s' % self.vmIp
-            print '\tRemember to stop the machine when finished'
+            self._printStep('Machine ready for use')
+            msg = '\n\tMachine IP: %s\tRemember to stop the machine when finished' % self.vmIp
+            Util.printInfo(msg)
 
     def _waitMachineNetworkUpOrAbort(self):
         self._printStep('Waiting for machine network to start')
         if not waitUntilPingOrTimeout(self.vmAddress, self.vmPingTimeout):
             msg = 'Unable to ping VM in %i seconds (id=%s, ip=%s)' % \
-                                    (self.vmPingTimeout, self.vmId, self.vmAddress)
+                  (self.vmPingTimeout, self.vmId, self.vmAddress)
             self._printError(msg)
             self._stopMachine()
 
@@ -331,9 +331,9 @@ class Creator(object):
 
     def _retrieveManifest(self):
         self._printStep('Retrieving image manifest')
-        
+
         configHolder = self.configHolder.copy()
-        
+
         downloader = ManifestDownloader(configHolder)
         self.manifestObject = downloader.getManifestInfo(self.image)
         self.manifest = self.manifestObject.tostring()
@@ -362,6 +362,10 @@ class Creator(object):
 
         self._setUpExtraRepositories()
 
+        self.printDetail('Updating installer')
+
+        ret = self._doInstallerUpdate()
+
         self.printDetail('Installing packages: %s' % self.packages)
 
         ret = self._doInstallPackagesRemotly(self.packages)
@@ -382,7 +386,7 @@ class Creator(object):
         extraReposList = self.extraOsReposUrls.split(',')
 
         if self.installer == 'yum':
-            for i,repoUrl in enumerate(extraReposList):
+            for i, repoUrl in enumerate(extraReposList):
                 repoName = getHostnameFromUri(repoUrl)
                 cmd = """cat >> /etc/yum.repos.d/%(name)s.repo << EOF
 [%(name)s]
@@ -391,14 +395,14 @@ baseurl=%(url)s
 gpgcheck=0
 enabled=1
 EOF
-""" % {'name' : '%s-%i'%(repoName,i), 'id': i, 'url' : repoUrl}
+""" % {'name': '%s-%i' % (repoName, i), 'id': i, 'url': repoUrl}
         elif self.installer == 'apt':
             for repoUrl in extraReposList:
                 repoName = getHostnameFromUri(repoUrl)
                 cmd = """cat >> /etc/apt/sources.list.d/%(reponame)s.list  << EOF
 deb %(repourl)s
 EOF
-""" % {'reponame' : repoName, 'repourl' : repoUrl}
+""" % {'reponame': repoName, 'repourl': repoUrl}
 
         self._sshCmdWithOutput(cmd)
 
@@ -407,6 +411,10 @@ EOF
         cmd += ' '.join(packages.split(','))
         return self._sshCmd(cmd, stderr=self.stderr, stdout=self.stdout)
 
+    def _doInstallerUpdate(self):
+        cmd = self._buildUpdaterCommand()
+        return self._sshCmd(cmd, stderr=self.stderr, stdout=self.stdout)
+
     def _buildInstallerCommand(self):
         if self.installer == 'yum':
             return yumInstallCmd
@@ -442,14 +450,14 @@ EOF
         def __tellScriptNameAndArgs(script):
             scriptNameAndArgs = os.path.basename(script)
             scriptNameAndArgsList = scriptNameAndArgs.split(' ', 1)
-            if len(scriptNameAndArgsList) == 1: # no arguments given
+            if len(scriptNameAndArgsList) == 1:  # no arguments given
                 scriptNameAndArgsList = scriptNameAndArgsList + ['']
             return scriptNameAndArgsList
 
         def _uploadScript(script):
 
             scriptName, args = __tellScriptNameAndArgs(script)
-            
+
             scriptDirectory = Util.sanitizePath(os.path.dirname(script))
             scriptPathLocal = os.path.abspath(os.path.join(scriptDirectory, scriptName))
             scriptPathRemote = '/tmp/%s' % scriptName
@@ -457,7 +465,7 @@ EOF
             rc, output = self._scpWithOutput(scriptPathLocal, 'root@%s:%s' % (self.vmAddress, scriptPathRemote))
             if rc != 0:
                 self._printError('An error occurred while uploading script %s\n%s' % (script, output))
-            
+
             self._sshCmdWithOutput('chmod 0755 %s' % scriptPathRemote)
 
             return scriptPathRemote, args
@@ -501,7 +509,7 @@ EOF
             if rc != 0:
                 self._printError('An error occurred while uploading recipe')
             self._sshCmdWithOutput('chmod 0755 %s' % scriptPath)
-    
+
             rc = self._sshCmd(scriptPath, throwOnError=False, pseudoTTY=True)
             if rc != 0:
                 self._printError('An error occurred while executing user recipe.')
@@ -518,6 +526,7 @@ EOF
         return Util.scp(src, dst, self.userPrivateKeyFile,
                         verboseLevel=self.verboseLevel, verboseThreshold=Util.VERBOSE_LEVEL_DETAILED,
                         stderr=self.stderr, stdout=self.stdout, **kwargs)
+
     def _scpWithOutput(self, src, dst):
         return self._scp(src, dst, withOutput=True)
 
@@ -552,12 +561,13 @@ EOF
 
     def getVmId(self):
         return self.vmId
-    
+
     def getVmState(self):
         return self.runner.getVmState(self.vmId)
 
-class CreatorBaseListener(object):
 
+# FIXME: This should be treated as a log handler rather than an ad hoc class.
+class CreatorBaseListener(object):
     def __init__(self, verbose=False):
         if verbose:
             self.write = self.__beVerbose
