@@ -54,9 +54,6 @@ VERBOSE_LEVEL_QUIET = 0
 VERBOSE_LEVEL_NORMAL = 1
 VERBOSE_LEVEL_DETAILED = 2
 
-EMPHASIS_START = '\033[1;31m'
-EMPHASIS_STOP = '\033[0m'
-
 # Environment variable names
 envEndpoint = 'STRATUSLAB_ENDPOINT'
 userConfigFileSelectedSection = 'STRATUSLAB_USER_CONFIG_SECTION'
@@ -68,6 +65,7 @@ SSH_CONNECTION_RETRY_SLEEP_MAX = 60
 
 def getShareDir():
     paths = [Defaults.SHARE_DIR,
+             os.path.join(utilPath, 'share'),
              os.path.join(utilPath, '..', '..', '..', 'share'),
              os.path.join(utilPath, '..', '..', '..', '..', 'share'),
              os.path.join(utilPath, '..', '..', 'resources', 'share')]
@@ -80,6 +78,7 @@ def getShareDir():
 
 def getTemplateDir():
     paths = [Defaults.TEMPLATE_DIR,
+             os.path.join(utilPath, 'share', 'template'),
              os.path.join(utilPath, '..', '..', '..', 'share', 'template'),
              os.path.join(utilPath, '..', '..', '..', '..', 'share', 'template'),
              os.path.join(utilPath, '..', '..', 'resources', 'share', 'template')]
@@ -91,7 +90,8 @@ def getTemplateDir():
     raise Exception("could not locate template directory; tried:\n%s" % "\n".join(paths))
 
 def getResourcesDir():
-    paths = [Defaults.TEMPLATE_DIR,
+    paths = [Defaults.RESOURCES_DIR,
+             os.path.join(utilPath, 'share', 'resources'),
              os.path.join(utilPath, '..', '..', '..', 'share', 'resources'),
              os.path.join(utilPath, '..', '..', '..', '..', 'share', 'resources'),
              os.path.join(utilPath, '..', '..', 'resources', 'share', 'resources')]
